chibi-scheme 0.1.0

Rust bindings to chibi-scheme
docs.rs failed to build chibi-scheme-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.